#ifndef NT2_INCLUDE_FUNCTIONS_FAST_SINCOSD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_FAST_SINCOSD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/fast_sincosd.hpp>

#endif
